all.Ritms<-function(){
     cat("\n")
     note_for_Ritss_input()
     cat("\n")
     note_for_close_window()
     RitMSpar<-data.frame(subject=c(1,2),LPV=c(0),D=c(0),tau=c(0),ts=c(0),c=c(0))
     RitMSpar<-edit(RitMSpar)
##     RitMSpar<-zmscheck(RitMSpar)
     cat("\n")
     Rit.ms(length(RitMSpar$subject),RitMSpar$c,RitMSpar$ts,RitMSpar$tau,RitMSpar$D,RitMSpar$LPV)
     note_for_convergence_plots()
     note_for_plot()
     convergence_plots_con()
     note_for_Ritss_output()
     show(samplesStats("*"))
     cat("\n") 
     C<-Ritcpr(samplesStats("ka"),RitMSpar$D,RitMSpar$tau,RitMSpar$ts)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mg/L)")
     output1<-coutput
     show(coutput)
     C<-Ritcpr(samplesStats("ka"),RitMSpar$D,RitMSpar$tau,RitMSpar$tau)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output2<-coutput
     show(coutput)    
     cat("\n") 
     cal.again()
}